@@ -1,4 +1,4 @@
-{-# LANGUAGE BangPatterns, OverloadedStrings, CPP #-}
+{-# LANGUAGE BangPatterns, OverloadedStrings #-}
 
 module Network.HPACK.HeaderBlock.Integer (
     encode
@@ -7,15 +7,11 @@ module Network.HPACK.HeaderBlock.Integer (
   , decodeInteger
   ) where
 
-#if __GLASGOW_HASKELL__ < 709
-import Control.Applicative ((<$>))
-#endif
 import Data.Array (Array, listArray)
 import Data.Array.Base (unsafeAt)
-import Data.Bits ((.&.), shiftR, testBit)
-import Data.ByteString (ByteString)
-import Data.Word (Word8)
-import Network.HPACK.Buffer
+import Network.ByteOrder
+
+import Imports
 
 -- $setup
 -- >>> import qualified Data.ByteString as BS
@@ -37,25 +33,25 @@ if I < 2^N - 1, encode I on N bits
 -}
 
 encodeInteger :: Int -> Int -> IO ByteString
-encodeInteger n i = withTemporaryBuffer 4096 $ \wbuf -> encode wbuf id n i
+encodeInteger n i = withWriteBuffer 4096 $ \wbuf -> encode wbuf id n i
 
--- Using writeWord8 is faster than using internals directly.
+-- Using write8 is faster than using internals directly.
 {-# INLINABLE encode #-}
-encode :: WorkingBuffer -> (Word8 -> Word8) -> Int -> Int -> IO ()
+encode :: WriteBuffer -> (Word8 -> Word8) -> Int -> Int -> IO ()
 encode wbuf set n i
-  | i < p     = writeWord8 wbuf $ set $ fromIntegral i
+  | i < p     = write8 wbuf $ set $ fromIntegral i
   | otherwise = do
-        writeWord8 wbuf $ set $ fromIntegral p
+        write8 wbuf $ set $ fromIntegral p
         encode' (i - p)
   where
     !p = powerArray `unsafeAt` (n - 1)
     encode' :: Int -> IO ()
     encode' j
-      | j < 128   = writeWord8 wbuf $ fromIntegral j
+      | j < 128   = write8 wbuf $ fromIntegral j
       | otherwise = do
           let !q = j `shiftR` 7
               !r = j .&. 0x7f
-          writeWord8 wbuf $ fromIntegral (r + 128)
+          write8 wbuf $ fromIntegral (r + 128)
           encode' q
 
 ----------------------------------------------------------------
@@ -95,7 +91,7 @@ decode n w rbuf
     !i = fromIntegral w
     decode' :: Int -> Int -> IO Int
     decode' m j = do
-        !b <- fromIntegral <$> getByte rbuf
+        !b <- readInt8 rbuf
         let !j' = j + (b .&. 0x7f) * 2 ^ m
             !m' = m + 7
             !cont = b `testBit` 7
