@@ -1,5 +1,4 @@
 {-# LANGUAGE BangPatterns #-}
-{-# LANGUAGE CPP #-}
 {-# LANGUAGE RecordWildCards #-}
 
 module Network.HTTP2.Priority.PSQ (
@@ -14,10 +13,6 @@ module Network.HTTP2.Priority.PSQ (
   , delete
   ) where
 
-#if __GLASGOW_HASKELL__ < 709
-import Control.Applicative ((<$>))
-import Data.Word (Word)
-#endif
 import Data.Array (Array, listArray, (!))
 import Data.IntPSQ (IntPSQ)
 import qualified Data.IntPSQ as P
@@ -30,7 +25,7 @@ type Deficit = Word -- Deficit can be overflowed
 
 -- | Internal representation of priority in priority queues.
 --   The precedence of a dequeued entry should be specified
---   to 'enqueue' when the entry is enqueued again.
+--   to enqueue when the entry is enqueued again.
 data Precedence = Precedence {
     deficit    :: {-# UNPACK #-} !Deficit
   , weight     :: {-# UNPACK #-} !Weight
