@@ -5,11 +5,13 @@ import Test.Hspec
 import Test.Hspec.QuickCheck
 import qualified Data.ByteString as BS
 
-dual :: Int -> Int -> Bool
-dual n i = decode n w (BS.pack ws) == x
-  where
-    w:ws = encode n x
-    x = abs i
+dual :: Int -> Int -> Expectation
+dual n i = do
+    let x = abs i
+    bs <- encodeInteger n x
+    let Just (w, ws) = BS.uncons bs
+    x' <- decodeInteger n w ws
+    x `shouldBe` x'
 
 spec :: Spec
 spec = do
